<?php
/**
 * Plugin Name: Rainbow Display
 * Description: A plugin to display a rainbow with all the colors of the new pride flag at the bottom of the screen.
 * Version: 1.1
 * Author: Fabio Huwyler
 */

// Enqueue the CSS for the rainbow
function rd_enqueue_rainbow_styles() {
    wp_enqueue_style('rainbow-display', plugins_url('rainbow-style.css', __FILE__));
}
add_action('wp_enqueue_scripts', 'rd_enqueue_rainbow_styles');

// Display the rainbow at the footer of the site
function rd_display_rainbow() {
    $display_setting = get_option('rd_display_option', 'front_page');
    $rainbow_height = get_option('rd_rainbow_height', '50px'); // default height of 50px

    $base_rainbow_height = 50; // our baseline height
    $height_difference = intval(str_replace('px', '', $rainbow_height)) - $base_rainbow_height;

    $circle_border_thickness = 5 + ($height_difference / 10);
    $circle_margin = 10 + ($height_difference / 10); 

    if ($display_setting === 'everywhere' || ($display_setting === 'front_page' && is_front_page())) {
        echo '<div class="rainbow" style="height:' . esc_attr($rainbow_height) . ';"></div>';
        $circle_diameter = intval(str_replace('px', '', $rainbow_height)) * 0.6 . 'px';
        echo '<div class="rainbow-circle" style="width: ' . esc_attr($circle_diameter) . '; height: ' . esc_attr($circle_diameter) . '; border-width: ' . esc_attr($circle_border_thickness) . 'px; margin: ' . esc_attr($circle_margin) . 'px;"></div>';
    }
}
add_action('wp_footer', 'rd_display_rainbow');

// Admin settings
function rd_rainbow_menu() {
    add_options_page('Rainbow Display Settings', 'Rainbow Display', 'manage_options', 'rainbow-display', 'rd_rainbow_settings_page');
}
add_action('admin_menu', 'rd_rainbow_menu');

function rd_rainbow_settings_page() {
    ?>
    <div class="wrap">
        <h2>Rainbow Display Settings</h2>
        <form method="post" action="options.php">
            <?php
            settings_fields('rainbow_display_settings');
            do_settings_sections('rainbow-display');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

function rd_display_settings_init() {
    add_settings_section('rainbow_settings_section', 'Rainbow Settings', null, 'rainbow-display');
    
    // Display setting
    add_settings_field('rd_display_option', 'Where should the rainbow be displayed?', 'rd_display_option_callback', 'rainbow-display', 'rainbow_settings_section');
    register_setting('rainbow_display_settings', 'rd_display_option');
    
    // Rainbow height setting
    add_settings_field('rd_rainbow_height', 'Rainbow Height (px)', 'rd_rainbow_height_callback', 'rainbow-display', 'rainbow_settings_section');
    register_setting('rainbow_display_settings', 'rd_rainbow_height');
}

add_action('admin_init', 'rd_display_settings_init');

function rd_display_option_callback() {
    $display_option = get_option('rd_display_option', 'front_page');
    echo '<select name="rd_display_option">
            <option value="front_page"' . selected($display_option, 'front_page', false) . '>Front Page only</option>
            <option value="everywhere"' . selected($display_option, 'everywhere', false) . '>Everywhere</option>
         </select>';
}

function rd_rainbow_height_callback() {
    $rainbow_height = get_option('rd_rainbow_height', '50px');
    $height_options = array('30px', '40px', '50px', '60px', '70px', '80px', '90px', '100px'); // predetermined heights
    echo '<select name="rd_rainbow_height">';
    foreach ($height_options as $option) {
        echo '<option value="' . esc_attr($option) . '"' . selected($rainbow_height, $option, false) . '>' . esc_html($option) . '</option>';
    }
    echo '</select>';
}
